@@ -33,9 +33,10 @@
 #  define KGUIADDONS_DEPRECATED_NO_EXPORT KGUIADDONS_NO_EXPORT KGUIADDONS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KGUIADDONS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KGUIADDONS_NO_DEPRECATED
+#    define KGUIADDONS_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
